# Release 1.0.1

Please see the [Release 1.0.0 release notes](v1_0_0.md) for details on the first cut.

Patches on top of v1.0.0 involve fixing a regression when running Tern inside of a container.

## Patches
```
7c74676 cleanup: remove unnecessary blank lines
1e54353 Delete bind_mount argument from clean_working_dir
e1f11b0 Set working dir based on --bind_mount CLI option
d52bfd1 Clean working dir the same for --bind-mount option
b7cf1c1 Update Dockerfile to run in container
61a881d Change bind_mount CLI option to store value
a7f4dbf Dockerfile: add tar dependency
52daca5 release: New post release flow and corrections
56b18b9 docs: Tern Lab tweaks
245d6fe docs: install `wheel` as part of setup in the lab
267497d docs: add git to the install dependencies in the lab tutorial
88e7d8e docs: fix a typo in the lab tutorial
791c260 docs: fix JSON report generation command in lab tutorial
```
